Module: FREDAPI::Client::Series::Search

Includes:
RelatedTags, Tags
Included in:
FREDAPI::Client::Series
Defined in:
lib/fredapi/client/series/search.rb,
lib/fredapi/client/series/search/tags.rb,
lib/fredapi/client/series/search/related_tags.rb

Overview

Search module for fred/series/search endpoint

Defined Under Namespace

Modules: RelatedTags, Tags

Instance Method Summary collapse

Methods included from RelatedTags

#series_search_related_tags

Methods included from Tags

#series_search_tags

Instance Method Details

#series_search(opts = {}) ⇒ Hashie::Mash

Get economic data series that match keywords

Parameters:

  • opts (Hash) (defaults to: {}) —

    options hash of parameters

Options Hash (opts):

  • api_key (Integer) —

    32 character alpha-numeric lowercase string

  • file_type (String) —

    A key or file extension that indicates the type of file to send

  • series_id (Integer) —

    The id for a series

  • search_text (String) —

    The words to match against economic data series

  • search_type (String) —

    Determines the type of search to perform

  • realtime_start (String) —

    The start of the real-time period

  • realtime_end (String) —

    The end of the real-time period

  • limit (Integer) —

    The maximum number of results to return

  • offset (Integer) —

    Non-negative integer

  • order_by (String) —

    Order results by values of the specified attribute

  • sort_order (String) —

    Sort results is ascending or descending order for attribute values specified by order_by

  • filter_variable (String) —

    The attribute to filter results by

  • filter_value (String) —

    The attribute to filter results by

  • tag_names (String) —

    A semicolon delimited list of tags to find related tags for

Returns:

  • (Hashie::Mash) —

    Hash containing the results



28
29
30
# File 'lib/fredapi/client/series/search.rb', line 28

def series_search opts={}
  get "fred/series/search", opts
end