Method: FREDAPI::Client::Tags#tags
- Defined in:
- lib/fredapi/client/tags.rb
#tags(opts = {}) ⇒ Hashie::Mash
Get all tags, search for tags, or get tags by name
Parameters:
-
opts
(Hash)
(defaults to: {})
—
options hash of parameters
Options Hash (opts):
-
api_key
(Integer)
—
32 character alpha-numeric lowercase string
-
file_type
(String)
—
A key or file extension that indicates the type of file to send
-
realtime_start
(String)
—
The start of the real-time period
-
realtime_end
(String)
—
The end of the real-time period
-
tag_group_id
(String)
—
A tag group id to filter tags by type
-
tag_names
(String)
—
A semicolon delimited list of tags to find related tags for
-
search_text
(String)
—
The words to find matching tags with
-
limit
(Integer)
—
The maximum number of results to return
-
offset
(Integer)
—
Non-negative integer
-
order_by
(String)
—
Order results by values of the specified attribute
-
sort_order
(String)
—
Sort results is ascending or descending order for attribute values specified by order_by
Returns:
-
(Hashie::Mash)
—
Hash containing the results
23 24 25 |
# File 'lib/fredapi/client/tags.rb', line 23 def tags opts={} get "fred/tags", opts end |